# tcpb-client

Python client to communicate with TeraChem running in server mode.

Client uses C-style sockets for communication and Protocol Buffers for data serialization.

Structured input/output data from TeraChem running in server mode. Full access to all files written by TeraChem server if using TeraChem Frontend.
